﻿--[[
MobileVault
Author: Michael Joseph Murray aka Starinnia of Lothar(US) aka Lyte of Lothar(US)
Please see license.txt for details.
$Revision: 84 $
$Date: 2009-10-27 23:45:06 +0000 (Tue, 27 Oct 2009) $
Project Version: r85
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2009 Michael J. Murray aka Starinnia of Lothar
All rights reserved unless otherwise explicitly stated.
]]

MobileVault = LibStub("AceAddon-3.0"):NewAddon("MobileVault", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("MobileVault")

--deal with keybinding stuff
BINDING_HEADER_MOBILEVAULT = "Mobile Vault"
BINDING_NAME_MGVTOGGLE = L["Toggle Frame"]

--create our LDB launcher
LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("MobileVault", {
	type = "launcher",
	label = "MobileVault",
	OnClick = function(_, msg)
		if msg == "LeftButton" then
			--open vault frame
			MobileVault:ShowVaultFrame()
		elseif msg == "RightButton" then
			--open config
			LibStub("AceConfigDialog-3.0"):SetDefaultSize("MobileVault", 500, 550)
			LibStub("AceConfigDialog-3.0"):Open("MobileVault")
		end
	end,
	icon = [[Interface\AddOns\MobileVault\icon]],
	OnTooltipShow = function(tooltip)
		if not tooltip or not tooltip.AddLine then return end
		tooltip:AddLine("MobileVault")
		tooltip:AddLine("|cffffff00" .. L["Click|r to toggle the Vault window"])
		tooltip:AddLine("|cffffff00" .. L["Right-click|r to open the options menu"])
	end,
})

function MobileVault:OnInitialize()
	local defaults = {
		profile = {
			position = {},
			guildTooltips = {
				['*'] = true,
			},
			frameColor = {0, 0, 0},
			highlightColor = {0, 0, 1},
			itemBorderColor = {1, 1, 1},
			selectedColor = {1, 1, 1},
			tabBorderColor = {0, 0, 0},
			textColor = {1, 1, 1},
			frameAlpha = 1,
			iconAlpha = 1,
			tooltipColor = "eda55f",
			itemPadding = 0,
			tabButtonSpacing = 15,
			strata = "LOW",
		},
		realm = {
			['*'] = {
				links = {
					['*'] = {},
				},
				info = {
					['*'] = {},
				},
				tabs = {
					names = {},
					textures = {},
				},
			},
		},
	}
	
	self.db = LibStub("AceDB-3.0"):New("MobileVaultDB", defaults, "Default")
	self.guilds = self.db.realm
	self.db.RegisterCallback(self, "OnProfileReset", "Reset")
	self.db.RegisterCallback(self, "OnProfileCopied", "Refresh")
	self.db.RegisterCallback(self, "OnProfileChanged", "Refresh")
	
	self:SetupConfig()
	
	_G["SlashCmdList"]["MOBILEVAULT_MAIN"] = function(s)
		if string.lower(s) == "open" then
			--open vault frame
		elseif strtrim(s) == "" then
			LibStub("AceConfigDialog-3.0"):SetDefaultSize("MobileVault", 500, 550)
			LibStub("AceConfigDialog-3.0"):Open("MobileVault")
		else
			--display help dialog
		end
	end
	_G["SLASH_MOBILEVAULT_MAIN1"] = "/mgv"
	_G["SLASH_MOBILEVAULT_MAIN2"] = "/mobilevault"
end

function MobileVault:OnEnable()
	self:RegisterEvent("GUILDBANKFRAME_OPENED")
	self:RegisterEvent("GUILDBANKBAGSLOTS_CHANGED", "ScanPage")
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("PLAYER_GUILD_UPDATE", "ObtainGuildName")
	
	self.frame = self:CreateVaultFrame()
	self.activePage = 0
end

function MobileVault:Reset()
	
end

function MobileVault:Refresh()
	
end

--take the given guild and page and show that page's items in the frame
function MobileVault:Populate(guild, page)
	if page == 0 then
		page = next(self.guilds[guild].links)
	end
	
	local itemName, itemLink, itemTexture
	for i = 1, 98 do
		itemName, itemLink, _, _, _, _, _, _, _, itemTexture = GetItemInfo(self.guilds[guild].links[page][i])
		self.frame.items[i].tex:SetTexture(itemTexture)
		self.frame.items[i].tex:SetTexCoords(0, 1, 0, 1)
		if self.guilds[guild].info[page][i] > 1 then
			self.frame.items[i].count:SetText(self.guilds[guild].info[page][i])
		end
		self.frame.items[i].item = itemLink
	end
end

--clear the currently displayed items
function MobileVault:Unpopulate()
	for i = 1, 98 do
		self.frame.items[i].tex:SetTexture(nil)
		self.frame.items[i].count:SetText("")
		self.frame.items[i].item = nil
	end
end

function MobileVault:PLAYER_ENTERING_WORLD()
	self:UnregisterEvent("PLAYER_ENTERING_WORLD") --only want this code to run once during login/reload
	self:ScheduleTimer("ObtainGuildName", 2) --need a slight delay after PEW to get guild information
end

function MobileVault:ObtainGuildName()
	if IsInGuild() then
		if self.noGuild then self.noGuild = nil end
		self.guildName = GetGuildInfo("player")
		self.activeGuild = self.guildName
	else
		self.noGuild = true
		self.guildName = next(self.guilds)
		self.activeGuild = self.guildName
	end
end

function MobileVault:GUILDBANKFRAME_OPENED()
	self.guilds[self.guildName].guildfunds = self:GetMoneyString()
	self.guilds[self.guildName].hasData = true
	self.guilds[self.guildName].numtabs = GetNumGuildBankTabs()
end

local num, itemString
function MobileVault:ScanPage()
	if GuildBankFrame and GuildBankFrame:IsVisible() then
		local page = GetCurrentGuildBankTab()
		--98 slots on a page
		for slot = 1, 98 do
			--see if the slot has an item in it
			if GetGuildBankItemLink(page, slot) then
				--if there is link, parse the ID and place that in table w/ key = slot
				_, _, itemString = string.find(GetGuildBankItemLink(page, slot), "^|c%x+|H(.+)|h%[.+%]")
				self.guilds[self.guildName].links[page][slot] = itemString
				
				--get item info too, need for stack sizes in image
				_, num = GetGuildBankItemInfo(page, slot)
				self.guilds[self.guildName].info[page][slot] = num
			else
				--if there is no link, slot is empty... fill slot w/ empty string
				--needed to keep consistent tables with keys from 1 to 98
				self.guilds[self.guildName].links[page][slot] = "empty"
				self.guilds[self.guildName].info[page][slot] = "empty"
			end
			num, itemString = nil, nil
		end
		
		--save a timestamp
		self.guilds[self.guildName].lastScan = date(L["date_format"]).." "..L["at"]..self:TimeStamp()
		
		--save the tab info
		local name, icon = GetGuildBankTabInfo(page)
		self.guilds[self.guildName].tabs.textures[page] = icon
		self.guilds[self.guildName].tabs.names[page] = name
	end
end

function MobileVault:TimeStamp()
	local hour, minute = GetGameTime()
	if minute < 10 then
		minute = "0"..minute
	end
	
	if hour == 0 then
		return string.format(" %s:%s %s", "12", minute, L["AM"])
	elseif hour == 12 then
		return string.format(" %s:%s %s", hour, minute, L["PM"])
	elseif hour > 12 then
		return string.format(" %s:%s %s", (hour-12), minute, L["PM"])
	else
		return string.format(" %s:%s %s", hour, minute, L["AM"])
	end
end

local goldAbrv = L["g"]
local silverAbrv = L["s"]
local copperAbrv = L["c"]
function MobileVault:GetMoneyString()
	local money = GetGuildBankMoney()
	local gold = (money - (money % 10000)) / 10000
	money = money % 10000
	local silver = (money - (money % 100)) / 100
	money = money % 100
	
	return string.format("%s|cff%s%s|r %s|cff%s%s|r %s|cff%s%s|r", gold, "eda55f", goldAbrv, silver, "c7c7cf", silverAbrv, copper, "ffd700", copperAbrv)
end

----------------------------------------------------------------------------------------------
--				TOOLTIP FUNCTIONS				     --
----------------------------------------------------------------------------------------------

local function AddItemCounts(frame, itemLink)

end

local function HookIt(tt)
	tt:HookScript("OnTooltipSetItem", function(self, ...)
		local itemLink = select(2, self:GetItem())
		if itemLink and GetItemInfo(itemLink) then
			AddItemCounts(self, itemLink)
		end
	end)
end

HookIt(GameTooltip)
HookIt(ItemRefTooltip)
